@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: ingo/lib/Storage.php,v 1.43.8.19 2008/07/06 22:46:21 jan Exp $
+ * $Horde: ingo/lib/Storage.php,v 1.43.8.22 2009/07/24 08:57:03 jan Exp $
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -281,7 +281,7 @@ class Ingo_Storage {
             break;
 
         case INGO_STORAGE_ACTION_MOVE:
-            $ob->label = _("Deliver to folder");
+            $ob->label = _("Deliver to folder...");
             $ob->type = 'folder';
             $ob->flags = true;
             break;
@@ -292,22 +292,22 @@ class Ingo_Storage {
             break;
 
         case INGO_STORAGE_ACTION_REDIRECT:
-            $ob->label = _("Redirect to");
+            $ob->label = _("Redirect to...");
             break;
 
         case INGO_STORAGE_ACTION_REDIRECTKEEP:
-            $ob->label = _("Deliver into my Inbox and redirect to");
+            $ob->label = _("Deliver into my Inbox and redirect to...");
             $ob->flags = true;
             break;
 
         case INGO_STORAGE_ACTION_MOVEKEEP:
-            $ob->label = _("Deliver into my Inbox and copy to");
+            $ob->label = _("Deliver into my Inbox and copy to...");
             $ob->type = 'folder';
             $ob->flags = true;
             break;
 
         case INGO_STORAGE_ACTION_REJECT:
-            $ob->label = _("Reject with reason");
+            $ob->label = _("Reject with reason...");
             break;
 
         case INGO_STORAGE_ACTION_FLAGONLY:
@@ -317,7 +317,7 @@ class Ingo_Storage {
             break;
 
         case INGO_STORAGE_ACTION_NOTIFY:
-            $ob->label = _("Notify email address");
+            $ob->label = _("Notify email address...");
             break;
         }
 
@@ -389,6 +389,19 @@ class Ingo_Storage {
         return $ob;
     }
 
+    /**
+     * Removes the user data from the storage backend.
+     * Stub for child class to override if it can implement.
+     *
+     * @param string $user The user name to delete filters for.
+     *
+     * @return mixed  True | PEAR_Error
+     */
+    function removeUserData($user)
+    {
+	return PEAR::raiseError(_("Removing user data is not supported with the current filter storage backend."));
+    }
+
 }
 
 /**
@@ -775,21 +788,6 @@ class Ingo_Storage_spam extends Ingo_Storage_rule {
     var $_folder = null;
     var $_level = 5;
 
-    function Ingo_Storage_spam()
-    {
-        // Attempt to get the default Spam folder from imp
-        if (in_array('imp', $GLOBALS['registry']->listApps())) {
-            $prefs = Prefs::factory($GLOBALS['conf']['prefs']['driver'],
-                                    'imp', Ingo::getUser(), '', null, false);
-            $prefs->retrieve();
-
-            $folder = $prefs->getValue('spam_folder', false);
-            if ($folder !== false) {
-                $this->_folder = $folder;
-            }
-        }
-    }
-
     function setSpamFolder($folder)
     {
         $this->_folder = $folder;
